==> pdf_slideshow-8.x-1.5.tar.gz: pdf_slideshow/src/Manager/PdfSlideshowImageManager.php <==
<?php

namespace Drupal\pdf_slideshow\Manager;

use Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway;
use Drupal\pdf_slideshow\Gateway\PdfSlideshowStorageGateway;

/**
 * Class PdfSlideshowImageManager.
 *
 * @package Drupal\pdf_slideshow\Manager
 */
class PdfSlideshowImageManager {

  /**
   * PdfSlideshowManager.
   *
   * @var \Drupal\pdf_slideshow\Gateway\PdfSlideshowStorageGateway
   */
  protected $pdfSlideshowStorageGateway;

  /**
   * PdfSlideshowEntityGateway.
   *
   * @var \Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway
   */
  protected $pdfSlideshowEntityGateway;

  /**
   * PdfSlideshowManager constructor.
   *
   * @param \Drupal\pdf_slideshow\Gateway\PdfSlideshowStorageGateway $pdfSlideshowStorageGateway
   *   PdfSlideshowStorageGateway.
   * @param \Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway $pdfSlideshowEntityGateway
   *   PdfSlideshowEntityGateway.
   */
  public function __construct(
    PdfSlideshowStorageGateway $pdfSlideshowStorageGateway,
    PdfSlideshowEntityGateway $pdfSlideshowEntityGateway
  ) {
    $this->pdfSlideshowStorageGateway = $pdfSlideshowStorageGateway;
    $this->pdfSlideshowEntityGateway = $pdfSlideshowEntityGateway;
  }

  /**
   * Get pdf image url.
   *
   * @param array $fileEntities
   *   File entities.
   * @param int|string $width
   *   Width.
   * @param int|string $height
   *   Height.
   * @param int|string $limit
   *   Limit.
   *
   * @return array|null
   *   Pdf files urls.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \ImagickException
   */
  public function getPdfImageUrls(
    array $fileEntities,
    $width,
    $height,
    $limit
  ) {
    $output = [];
    foreach ($fileEntities as $fileEntity) {
      $pdfImagesId = $this->pdfSlideshowStorageGateway->fetchPdfImageIds($fileEntity->id());
      if ($pdfImagesId) {
        $urls = $this->pdfSlideshowEntityGateway->getPdfFileImageUrls($pdfImagesId);
        if (count($urls) != intval($limit)) {
          $urls = $this->pdfSlideshowStorageGateway->persistPdfImageIds($fileEntity,
            $width, $height,
            $limit);
        }
      }
      else {
        $urls = $this->pdfSlideshowStorageGateway->persistPdfImageIds($fileEntity,
          $width, $height,
          $limit);
      }
      $output[] = $urls;
    }
    return $output;
  }

}

==> pdf_slideshow-8.x-1.6.tar.gz: pdf_slideshow/src/Manager/PdfSlideshowImageManager.php <==
<?php

namespace Drupal\pdf_slideshow\Manager;

use Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway;
use Drupal\pdf_slideshow\Gateway\PdfSlideshowStorageGateway;

/**
 * Class PdfSlideshowImageManager.
 *
 * @package Drupal\pdf_slideshow\Manager
 */
class PdfSlideshowImageManager {

  /**
   * PdfSlideshowManager.
   *
   * @var \Drupal\pdf_slideshow\Gateway\PdfSlideshowStorageGateway
   */
  protected $pdfSlideshowStorageGateway;

  /**
   * PdfSlideshowEntityGateway.
   *
   * @var \Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway
   */
  protected $pdfSlideshowEntityGateway;

  /**
   * PdfSlideshowManager constructor.
   *
   * @param \Drupal\pdf_slideshow\Gateway\PdfSlideshowStorageGateway $pdfSlideshowStorageGateway
   *   PdfSlideshowStorageGateway.
   * @param \Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway $pdfSlideshowEntityGateway
   *   PdfSlideshowEntityGateway.
   */
  public function __construct(
    PdfSlideshowStorageGateway $pdfSlideshowStorageGateway,
    PdfSlideshowEntityGateway $pdfSlideshowEntityGateway
  ) {
    $this->pdfSlideshowStorageGateway = $pdfSlideshowStorageGateway;
    $this->pdfSlideshowEntityGateway = $pdfSlideshowEntityGateway;
  }

  /**
   * Get pdf image url.
   *
   * @param array $fileEntities
   *   File entities.
   * @param int|string $width
   *   Width.
   * @param int|string $height
   *   Height.
   * @param int|string $limit
   *   Limit.
   *
   * @return array|null
   *   Pdf files urls.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \ImagickException
   */
  public function getPdfImageUrls(
    array $fileEntities,
    $width,
    $height,
    $limit
  ) {
    $output = [];
    foreach ($fileEntities as $fileEntity) {
      $pdfImagesId = $this->pdfSlideshowStorageGateway->fetchPdfImageIds($fileEntity->id());
      if ($pdfImagesId) {
        $urls = $this->pdfSlideshowEntityGateway->fetchPdfFileImageUrls($pdfImagesId);
        if (count($urls) != intval($limit)) {
          $urls = $this->pdfSlideshowStorageGateway->persistPdfImageIds($fileEntity,
            $width, $height,
            $limit);
        }
      }
      else {
        $urls = $this->pdfSlideshowStorageGateway->persistPdfImageIds($fileEntity,
          $width, $height,
          $limit);
      }
      $output[] = $urls;
    }
    return $output;
  }

}
